@@ -76,6 +76,23 @@ class ArticleDetail2(ArticleDetail):
     
 views.ArticleDetail = ArticleDetail2
 
+def get_queryset(self):
+    categories = [self.category,]
+    stack = [self.category,]
+
+    while stack:
+        category = stack.pop()
+        children = category.get_children()
+        for child in children:
+            categories.append(child)
+            stack.append(child)
+
+    return super(CategoryArticleList, self).get_queryset().filter(
+        categories__in=categories
+    ).distinct()
+
+CategoryArticleList.get_queryset = get_queryset
+
 from aldryn_newsblog.urls import urlpatterns
 from aldryn_newsblog.feeds import TagFeed, CategoryFeed
 
