@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 11182 2018-07-29 13:55:04Z Lavender $
+# $Id: cms_plugins.py 11227 2018-09-10 10:53:39Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-07-29 22:55:04 +0900 (週日, 29 七月 2018) $
-# $Revision: 11182 $
+# $Date: 2018-09-10 19:53:39 +0900 (週一, 10 九月 2018) $
+# $Revision: 11227 $
 
 from django.db.models import Count
 from django.template.loader import select_template
@@ -23,12 +23,14 @@ from cms.plugin_pool import plugin_pool
 from oscar.core.loading import get_model
 
 from Zephyrus.cms_oscar import settings 
-from Zephyrus.cms_oscar.models import OscarFeatured, OscarLatest
+from Zephyrus.cms_oscar.models import OscarFeatured, OscarLatest, OscarOffer
 from Zephyrus.cms_oscar.forms import OscarFeaturedForm, OscarLatestForm
 
 
 ProductRecord = get_model('analytics', 'ProductRecord')
 Product = get_model('catalogue', 'Product')
+ConditionalOffer = get_model('offer', 'ConditionalOffer')
+Condition = get_model('offer', 'Condition')
 
 if hasattr(Product, 'tags'):
     hasTags = True
@@ -103,6 +105,34 @@ class LatestPlugin(CMSPluginBase):
         })
         
         return context
+
+class OfferPlugin(CMSPluginBase):
+    model = OscarOffer
+    module = "Zephyrus Oscar"
+    name = "Offer Products"
+    render_template = settings.ZEPHYRUS_OSCAR_OFFER_DEFAULT_TEMPLATE
+    
+    def get_render_template(self, context, instance, placeholder):
+        return select_template([
+            instance.renderTemplate,
+            settings.ZEPHYRUS_OSCAR_OFFER_DEFAULT_TEMPLATE,
+        ])
+
+    def render(self, context, instance, placeholder):
+        products = []
+        for offer in instance.offer.all():
+            for p in offer.products():
+                if not p in products:
+                    products.append(p)
+
+        context.update({
+            'products': products,
+        })
+        
+        return context
+
+
     
 plugin_pool.register_plugin(FeaturedPlugin)
 plugin_pool.register_plugin(LatestPlugin)
+plugin_pool.register_plugin(OfferPlugin)
