@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11055 2018-05-14 09:46:32Z Lavender $
+# $Id: models.py 11226 2018-09-10 06:34:58Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-05-14 17:46:32 +0800 (週一, 14 五月 2018) $
-# $Revision: 11055 $
+# $Date: 2018-09-10 15:34:58 +0900 (週一, 10 九月 2018) $
+# $Revision: 11226 $
 
 from django.db import models
 
@@ -24,6 +24,8 @@ from oscar.core.loading import get_model
 from Zephyrus.cms_oscar import settings
 
 Category = get_model('catalogue', 'category')
+ConditionalOffer = get_model('offer', 'ConditionalOffer')
+
 
 class OscarFeatured(CMSPlugin):
     limit = models.PositiveIntegerField(default=6)
@@ -71,4 +73,20 @@ class OscarLatest(CMSPlugin):
         default=None,
         blank=True,
         null=True,
-    )
\ No newline at end of file
+    )
+
+class OscarOffer(CMSPlugin):
+    limit = models.PositiveIntegerField(default=6)
+
+    renderTemplate = models.CharField(
+        'Offer Template', max_length=150, blank=True,
+        choices=settings.ZEPHYRUS_OSCAR_OFFER_TEMPLATES,
+        default=settings.ZEPHYRUS_OSCAR_OFFER_DEFAULT_TEMPLATE,
+    )
+
+    offer = models.ManyToManyField(
+        ConditionalOffer,
+    )
+
+    def copy_relations(self, oldinstance):
+        self.offer = oldinstance.offer.all()
\ No newline at end of file
